import type { Equatable } from "@siteimprove/alfa-equatable";
import type * as json from "@siteimprove/alfa-json";
import type { Serializable } from "@siteimprove/alfa-json";
import { Option } from "@siteimprove/alfa-option";
import { Record } from "@siteimprove/alfa-record";
import { Result } from "@siteimprove/alfa-result";
import type { Numeric } from "../numeric/index.js";
/**
 * {@link https://drafts.css-houdini.org/css-typed-om/#numeric-typing}
 *
 * @remarks
 * The shared `Value` interface already uses the term "type" to denote the
 * different types of CSS values. We therefore use the term "kind" to denote
 * the type of a calculation.
 *
 * @internal
 */
export declare class Kind implements Equatable, Serializable {
    static of(kind?: Kind.Base): Kind;
    private static _empty;
    private readonly _kinds;
    private readonly _hint;
    protected constructor(kinds: Kind.Map, hint: Option<Kind.Hint>);
    get kinds(): Kind.Map;
    get hint(): Option<Kind.Hint>;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-match}
     */
    is(kind?: Kind.Base, value?: number, hinted?: boolean): boolean;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-add-two-types}
     */
    add(kind: Kind): Result<Kind, string>;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-multiply-two-types}
     */
    multiply(kind: Kind): Result<Kind, string>;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-invert-a-type}
     */
    invert(): Kind;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#apply-the-percent-hint}
     */
    apply(hint: Kind.Hint): Kind;
    equals(value: this): boolean;
    equals(value: unknown): value is this;
    toJSON(): Kind.JSON;
}
/**
 * @internal
 */
export declare namespace Kind {
    interface JSON {
        [key: string]: json.JSON;
        kinds: Array<[Base, number]>;
        hint: Hint | null;
    }
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-type}
     */
    type Map = Record<{
        [K in Base]: number;
    }>;
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-base-type}
     */
    type Base = Numeric.Dimension | "percentage";
    /**
     * {@link https://drafts.css-houdini.org/css-typed-om/#cssnumericvalue-percent-hint}
     */
    type Hint = Exclude<Kind.Base, "percentage">;
}
//# sourceMappingURL=kind.d.ts.map