import type { Equatable } from "@siteimprove/alfa-equatable";
import type { Serializable } from "@siteimprove/alfa-json";
import { Parser } from "@siteimprove/alfa-parser";
import type { Predicate } from "@siteimprove/alfa-predicate";
import { Slice } from "@siteimprove/alfa-slice";
import type * as json from "@siteimprove/alfa-json";
import type { Thunk } from "@siteimprove/alfa-thunk";
import type { Parser as CSSParser } from "./parser.js";
import { Token } from "./token.js";
/**
 * {@link https://drafts.csswg.org/css-syntax/#function}
 *
 * @public
 */
export declare class Function implements Iterable<Token>, Equatable, Serializable {
    static of(name: string, value: Iterable<Token>): Function;
    private readonly _name;
    private readonly _value;
    protected constructor(name: string, value: Array<Token>);
    get name(): string;
    get value(): Array<Token>;
    [Symbol.iterator](): Iterator<Token>;
    equals(value: unknown): value is this;
    toJSON(): Function.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Function {
    interface JSON {
        [key: string]: json.JSON;
        name: string;
        value: Array<Token.JSON>;
    }
    /**
     * {@link https://drafts.csswg.org/css-syntax/#consume-a-function}
     */
    const consume: CSSParser<Function>;
    const parse: <T>(query?: string | Predicate<Token.Function>, body?: CSSParser<T> | Thunk<CSSParser<T>>) => Parser<Slice<Token>, readonly [Function, T], string, []>;
}
//# sourceMappingURL=function.d.ts.map