import { Parser } from "@siteimprove/alfa-parser";
import type { Slice } from "@siteimprove/alfa-slice";
import type { Token } from "../../syntax/index.js";
import { Keyword } from "../textual/keyword.js";
import type { Angle, Number, Percentage } from "../numeric/index.js";
import { Current } from "./current.js";
import { Hex } from "./hex.js";
import { HSL } from "./hsl.js";
import { Named } from "./named.js";
import { RGB } from "./rgb.js";
import { System } from "./system.js";
/**
 * @public
 */
export type Color = Hex | Named | HSL | RGB | Current | System;
/**
 * @public
 */
export declare namespace Color {
    type Canonical = Current | System | RGB.Canonical;
    type JSON = Hex.JSON | Named.JSON | HSL.JSON | RGB.JSON | Keyword.JSON;
    const current: Current;
    function hex(value: number): Hex;
    function hsl<H extends Number.Canonical | Angle.Canonical, A extends Number.Canonical | Percentage.Canonical>(hue: H, saturation: Percentage<"percentage">, lightness: Percentage<"percentage">, alpha: A): HSL<H, A>;
    function named<C extends Named.Color>(color: C): Named<C>;
    function rgb<C extends Number.Canonical | Percentage.Canonical, A extends Number.Canonical | Percentage.Canonical>(red: C, green: C, blue: C, alpha: A): RGB<C, A>;
    function system(keyword: System.Keyword): System;
    /**
     * {@link https://drafts.csswg.org/css-color/#typedef-color}
     */
    const parse: Parser<Slice<Token>, Color, string, []>;
    function isTransparent(color: Color): boolean;
}
//# sourceMappingURL=color.d.ts.map