import { Err, Result } from "@siteimprove/alfa-result";
import { Parser } from "@siteimprove/alfa-parser";
import { Keyword } from "./textual/keyword.js";
import { Value } from "./value.js";
import { Token } from "../syntax/index.js";
import { Slice } from "@siteimprove/alfa-slice";
const { either } = Parser;
/**
 * @public
 */
export class ContainFlags extends Value {
    static of(size, inlineSize, layout, style, paint) {
        return new ContainFlags(size, inlineSize, layout, style, paint);
    }
    _size;
    _inlineSize;
    _layout;
    _style;
    _paint;
    constructor(size, inlineSize, layout, style, paint) {
        super("contain-flags", false);
        this._size = size;
        this._inlineSize = inlineSize;
        this._layout = layout;
        this._style = style;
        this._paint = paint;
    }
    get size() {
        return this._size;
    }
    get inlineSize() {
        return this._inlineSize;
    }
    get layout() {
        return this._layout;
    }
    get style() {
        return this._style;
    }
    get paint() {
        return this._paint;
    }
    resolve() {
        return this;
    }
    equals(value) {
        return (value instanceof ContainFlags &&
            value._size === this._size &&
            value._inlineSize === this._inlineSize &&
            value._layout === this._layout &&
            value._style === this._style &&
            value._paint === this._paint);
    }
    hash(hash) {
        hash
            .writeBoolean(this._size)
            .writeBoolean(this._inlineSize)
            .writeBoolean(this._layout)
            .writeBoolean(this._style)
            .writeBoolean(this._paint);
    }
    toJSON() {
        return {
            ...super.toJSON(),
            size: this._size,
            inlineSize: this._inlineSize,
            layout: this._layout,
            style: this._style,
            paint: this._paint,
        };
    }
    toString() {
        let keywords = [];
        if (this._size) {
            keywords.push("size");
        }
        if (this._inlineSize) {
            keywords.push("inline-size");
        }
        if (this._layout) {
            keywords.push("layout");
        }
        if (this._style) {
            keywords.push("style");
        }
        if (this._paint) {
            keywords.push("paint");
        }
        return keywords.join(" ");
    }
}
/**
 * @public
 */
(function (ContainFlags) {
    function isContainFlags(value) {
        return value instanceof ContainFlags;
    }
    ContainFlags.isContainFlags = isContainFlags;
    ContainFlags.parse = (input) => {
        let size;
        let layout;
        let style;
        let paint;
        while (true) {
            for (const [remainder] of Token.parseWhitespace(input)) {
                input = remainder;
            }
            if (size === undefined) {
                const result = Keyword.parse("size", "inline-size")(input);
                if (result.isOk()) {
                    [input, size] = result.get();
                    continue;
                }
            }
            if (layout === undefined) {
                const result = Keyword.parse("layout")(input);
                if (result.isOk()) {
                    [input, layout] = result.get();
                    continue;
                }
            }
            if (style === undefined) {
                const result = Keyword.parse("style")(input);
                if (result.isOk()) {
                    [input, style] = result.get();
                    continue;
                }
            }
            if (paint === undefined) {
                const result = Keyword.parse("paint")(input);
                if (result.isOk()) {
                    [input, paint] = result.get();
                    continue;
                }
            }
            break;
        }
        if (size === undefined &&
            layout === undefined &&
            style === undefined &&
            paint === undefined) {
            return Err.of("Expected at least one keyword");
        }
        return Result.of([
            input,
            ContainFlags.of(size?.value === "size", size?.value === "inline-size", layout !== undefined, style !== undefined, paint !== undefined),
        ]);
    };
})(ContainFlags || (ContainFlags = {}));
/**
 * @public
 */
export var Contain;
(function (Contain) {
    Contain.parse = either(Keyword.parse("none", "strict", "content"), ContainFlags.parse);
})(Contain || (Contain = {}));
//# sourceMappingURL=contain.js.map