import type { Hash } from "@siteimprove/alfa-hash";
import { Option } from "@siteimprove/alfa-option";
import { type Parser as CSSParser } from "../../../../syntax/index.js";
import { Color } from "../../../color/index.js";
import { LengthPercentage } from "../../../numeric/index.js";
import type { PartiallyResolvable, Resolvable } from "../../../resolvable.js";
import { Value } from "../../../value.js";
/**
 * {@link https://drafts.csswg.org/css-images/#color-stop}
 */
export declare class Stop<C extends Color = Color, P extends LengthPercentage = LengthPercentage> extends Value<"stop", Value.HasCalculation<[C, P]>> implements Resolvable<Stop.Canonical, Stop.Resolver>, PartiallyResolvable<Stop.PartiallyResolved, Stop.PartialResolver> {
    static of<C extends Color, P extends LengthPercentage>(color: C, position?: Option<P>): Stop<C, P>;
    private readonly _color;
    private readonly _position;
    protected constructor(color: C, position: Option<P>);
    get color(): C;
    get position(): Option<P>;
    resolve(resolver: Stop.Resolver): Stop.Canonical;
    partiallyResolve(resolver: Stop.PartialResolver): Stop.PartiallyResolved;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Stop.JSON;
    toString(): string;
}
export declare namespace Stop {
    type Canonical = Stop<Color.Canonical, LengthPercentage.Canonical>;
    type PartiallyResolved = Stop<Color.Canonical, LengthPercentage.PartiallyResolved>;
    interface JSON extends Value.JSON<"stop"> {
        color: Color.JSON;
        position: LengthPercentage.JSON | null;
    }
    type Resolver = LengthPercentage.Resolver;
    type PartialResolver = LengthPercentage.PartialResolver;
    function isStop(value: unknown): value is Stop;
    /**
     * {@link https://drafts.csswg.org/css-images/#typedef-linear-color-stop}
     */
    const parse: CSSParser<Stop>;
}
//# sourceMappingURL=stop.d.ts.map