import type { Comparable } from "@siteimprove/alfa-comparable";
import { Math } from "../../calculation/index.js";
import { Angle as BaseAngle } from "../../calculation/numeric/index.js";
import { type Parser as CSSParser } from "../../syntax/index.js";
import type { Unit } from "../../unit/index.js";
import type { Resolvable } from "../resolvable.js";
import { Dimension } from "./dimension.js";
import type { Numeric } from "./numeric.js";
/**
 * {@link https://drafts.csswg.org/css-values/#numbers}
 *
 * @public
 */
export type Angle<U extends Unit.Angle = Unit.Angle> = Angle.Calculated | Angle.Fixed<U>;
/**
 * {@link https://drafts.csswg.org/css-values/#numbers}
 *
 * @public
 */
export declare namespace Angle {
    type Canonical = Fixed<"deg">;
    type Resolver = {};
    /**
     * Angles that are the result of a calculation.
     */
    class Calculated extends Dimension.Calculated<"angle"> implements Resolvable<Canonical, never> {
        static of(value: Math<"angle">): Calculated;
        protected constructor(value: Math<"angle">);
        hasCalculation(): this is Calculated;
        resolve(resolver?: Numeric.GenericResolver): Canonical;
        equals(value: unknown): value is this;
    }
    /**
     * @public
     */
    namespace Calculated {
        interface JSON extends Dimension.Calculated.JSON<"angle"> {
        }
    }
    /**
     * Angles that are a fixed (not calculated) value.
     */
    class Fixed<U extends Unit.Angle = Unit.Angle> extends Dimension.Fixed<"angle", U> implements Resolvable<Canonical, never>, Comparable<Fixed<U>> {
        static of<U extends Unit.Angle>(value: number, unit: U): Fixed<U>;
        static of<U extends Unit.Angle>(value: BaseAngle<U>): Fixed<U>;
        protected constructor(value: number, unit: U);
        hasCalculation(): this is never;
        hasUnit<U extends Unit.Angle>(unit: U): this is Fixed<U>;
        withUnit<U extends Unit.Angle>(unit: U): Fixed<U>;
        scale(factor: number): Fixed<U>;
        resolve(): Canonical;
        /**
         * @internal
         */
        toBase(): BaseAngle<U>;
        equals(value: unknown): value is this;
    }
    /**
     * @public
     */
    namespace Fixed {
        interface JSON<U extends Unit.Angle = Unit.Angle> extends Dimension.Fixed.JSON<"angle", U> {
        }
    }
    type JSON = Calculated.JSON | Fixed.JSON;
    function isCalculated(value: unknown): value is Calculated;
    function isFixed(value: unknown): value is Fixed;
    function isAngle(value: unknown): value is Angle;
    function of<U extends Unit.Angle>(value: number, unit: U): Fixed<U>;
    function of<U extends Unit.Angle>(value: BaseAngle<U>): Fixed<U>;
    function of(value: Math<"angle">): Calculated;
    /**
     * {@link https://drafts.csswg.org/css-values/#number-value}
     */
    const parse: CSSParser<Angle>;
}
//# sourceMappingURL=angle.d.ts.map