import type { Hash } from "@siteimprove/alfa-hash";
import { Parser } from "@siteimprove/alfa-parser";
import type { Slice } from "@siteimprove/alfa-slice";
import type { PartiallyResolvable, Resolvable } from "../resolvable.js";
import { Value } from "../value.js";
import { type Parser as CSSParser, Token } from "../../syntax/index.js";
import { Box } from "../box.js";
import { Circle } from "./circle.js";
import { Inset } from "./inset.js";
import { Rectangle } from "./rectangle.js";
import { Ellipse } from "./ellipse.js";
import { Polygon } from "./polygon.js";
/**
 * @public
 */
export declare class Shape<S extends Shape.Basic = Shape.Basic, B extends Box.Geometry = Box.Geometry> extends Value<"shape", Value.HasCalculation<[S]>> implements Resolvable<Shape.Canonical, Shape.Resolver>, PartiallyResolvable<Shape.PartiallyResolved, Shape.PartialResolver> {
    static of<S extends Shape.Basic = Shape.Basic, B extends Box.Geometry = Box.Geometry>(shape: S, box: B): Shape<S, B>;
    private readonly _shape;
    private readonly _box;
    protected constructor(shape: S, box: B);
    get shape(): S;
    get box(): B;
    resolve(resolver: Shape.Resolver): Shape.Canonical;
    partiallyResolve(resolver: Shape.PartialResolver): Shape.PartiallyResolved;
    equals(value: Shape): boolean;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): Shape.JSON;
    toString(): string;
}
/**
 * @public
 */
export declare namespace Shape {
    type Canonical = Shape<Basic.Canonical, Box.Geometry>;
    /**
     * {@link https://drafts.csswg.org/css-shapes/#typedef-basic-shape}
     */
    type Basic = Circle | Ellipse | Inset | Polygon | Rectangle;
    namespace Basic {
        type Canonical = Circle.Canonical | Ellipse.Canonical | Inset.Canonical | Polygon.Canonical | Rectangle.Canonical;
        type JSON = Circle.JSON | Ellipse.JSON | Inset.JSON | Polygon.JSON | Rectangle.JSON;
        type Resolver = Circle.Resolver & Ellipse.Resolver & Inset.Resolver & Polygon.Resolver & Rectangle.Resolver;
        type PartiallyResolved = Circle.PartiallyResolved | Ellipse.PartiallyResolved | Inset.PartiallyResolved | Polygon.PartiallyResolved | Rectangle.Canonical;
        type PartialResolver = Circle.PartialResolver & Ellipse.PartialResolver & Inset.PartialResolver & Polygon.PartialResolver & Rectangle.Resolver;
        function partiallyResolve(resolver: PartialResolver): (value: Basic) => PartiallyResolved;
        /**
         * @remarks
         * This does not parse the deprecated `rect()` shape.
         *
         * @internal
         */
        const parse: Parser<Slice<Token>, Circle<import("./radius.js").Radius<import("../index.js").LengthPercentage | import("./radius.js").Radius.Side>, import("../index.js").Position<import("../position/keywords.js").Keywords.Horizontal, import("../position/keywords.js").Keywords.Vertical, import("../position/component.js").Component<import("../position/keywords.js").Keywords.Horizontal>, import("../position/component.js").Component<import("../position/keywords.js").Keywords.Vertical>>> | Ellipse<import("./radius.js").Radius<import("../index.js").LengthPercentage | import("./radius.js").Radius.Side>, import("../index.js").Position<import("../position/keywords.js").Keywords.Horizontal, import("../position/keywords.js").Keywords.Vertical, import("../position/component.js").Component<import("../position/keywords.js").Keywords.Horizontal>, import("../position/component.js").Component<import("../position/keywords.js").Keywords.Vertical>>> | Inset<Inset.Offset, import("./corner.js").Corner> | Polygon<Polygon.Fill, import("../index.js").LengthPercentage>, string, []>;
    }
    interface JSON extends Value.JSON<"shape"> {
        shape: Basic.JSON;
        box: Box.Geometry.JSON;
    }
    type Resolver = Basic.Resolver;
    type PartiallyResolved = Shape<Basic.PartiallyResolved, Box.Geometry>;
    type PartialResolver = Basic.PartialResolver;
    /**
     * @remarks
     * This does not parse the deprecated `rect()` shape.
     */
    const parse: CSSParser<Shape<Circle | Ellipse | Inset | Polygon>>;
}
//# sourceMappingURL=shape.d.ts.map