import type { Hash } from "@siteimprove/alfa-hash";
import { Option } from "@siteimprove/alfa-option";
import { Parser } from "@siteimprove/alfa-parser";
import { Number, Percentage } from "../numeric/index.js";
import type { Resolvable } from "../resolvable.js";
import { Function } from "./function.js";
type ToCanonical<T extends Number | Percentage<"percentage">> = T extends Number ? Number.Canonical : T extends Percentage ? Percentage.Canonical : Number.Canonical | Percentage.Canonical;
/**
 * Class representing a transformation that resizes an element in either 2D or 3D space.
 * Is parsed from either a scale() or scale3d() transform function or a value of the scale property.
 *
 * @public
 */
export declare class Scale<X extends Number.Canonical | Percentage.Canonical = Number.Canonical | Percentage.Fixed<"percentage">, Y extends Number.Canonical | Percentage.Canonical = Number.Canonical | Percentage.Fixed<"percentage">, Z extends Number.Canonical | Percentage.Canonical = Number.Canonical | Percentage.Fixed<"percentage">> extends Function<"scale", false> implements Resolvable<Scale.Canonical, never> {
    static of<X extends Number.Canonical | Percentage.Canonical, Y extends Number.Canonical | Percentage.Canonical>(x: X, y: Y): Scale<X, Y, never>;
    static of<X extends Number | Percentage<"percentage">, Y extends Number | Percentage<"percentage">>(x: X, y: Y): Scale<ToCanonical<X>, ToCanonical<Y>>;
    static of<X extends Number.Canonical | Percentage.Canonical, Y extends Number.Canonical | Percentage.Canonical, Z extends Number.Canonical | Percentage.Canonical>(x: X, y: Y, z: Z): Scale<X, Y, Z>;
    static of<X extends Number | Percentage<"percentage">, Y extends Number | Percentage<"percentage">, Z extends Number | Percentage<"percentage">>(x: X, y: Y, z: Z): Scale<ToCanonical<X>, ToCanonical<Y>, ToCanonical<Z>>;
    private readonly _x;
    private readonly _y;
    private readonly _z;
    protected constructor(x: X, y: Y, z?: Z);
    get kind(): "scale";
    get x(): X;
    get y(): Y;
    get z(): Option<Z>;
    resolve(): Scale.Canonical;
    equals(value: unknown): value is this;
    hash(hash: Hash): void;
    toJSON(): {
        z?: Number.Fixed.JSON | Percentage.Fixed.JSON | undefined;
        x: Number.Fixed.JSON | Percentage.Fixed.JSON;
        y: Number.Fixed.JSON | Percentage.Fixed.JSON;
        kind: "scale";
        type: "transform";
    };
    toString(): string;
}
/**
 * @public
 */
export declare namespace Scale {
    type Canonical = Scale;
    interface JSON extends Function.JSON<"scale"> {
        x: Number.Fixed.JSON | Percentage.Fixed.JSON;
        y: Number.Fixed.JSON | Percentage.Fixed.JSON;
        z: Number.Fixed.JSON | Percentage.Fixed.JSON;
    }
    function isScale(value: unknown): value is Scale;
    const parse: Parser<import("@siteimprove/alfa-slice").Slice<import("../../syntax/token.js").Token>, Scale<Number.Fixed | Percentage.Canonical, Number.Fixed | Percentage.Canonical, Number.Fixed | Percentage.Canonical>, string, []>;
    /**
     * {@link https://developer.mozilla.org/en-US/docs/Web/CSS/scale}
     */
    const parseProp: Parser<import("@siteimprove/alfa-slice").Slice<import("../../syntax/token.js").Token>, Scale<Number.Fixed | Percentage.Canonical, Number.Fixed | Percentage.Canonical, Number.Fixed | Percentage.Canonical>, string, []>;
}
export {};
//# sourceMappingURL=scale.d.ts.map